### Name: geom_bar
### Title: geom_bar
### Aliases: geom_bar GeomBar
### Keywords: hplot

### ** Examples
## Not run: 
##D # Generate data
##D c <- ggplot(mtcars, aes(factor(cyl)))
##D 
##D c + geom_bar()
##D c + geom_bar() + coord_flip()
##D c + geom_bar(fill="white", colour="darkgreen")
##D 
##D # Use qplot
##D qplot(factor(cyl), data=mtcars, geom="bar")
##D qplot(factor(cyl), data=mtcars, geom="bar", fill=factor(cyl))
##D 
##D # Stacked bar charts    
##D qplot(factor(cyl), data=mtcars, geom="bar", fill=factor(vs))
##D qplot(factor(cyl), data=mtcars, geom="bar", fill=factor(gear))
##D 
##D # Stacked bar charts are easy in ggplot2, but not effective visually, 
##D # particularly when there are many different things being stacked
##D ggplot(diamonds, aes(clarity, fill=cut)) + geom_bar()
##D ggplot(diamonds, aes(color, fill=cut)) + geom_bar() + coord_flip()
##D 
##D # Faceting is a good alternative:
##D ggplot(diamonds, aes(clarity)) + geom_bar() + 
##D   facet_wrap(~ cut)
##D # If the x axis is ordered, using a line instead of bars is another
##D # possibility:
##D ggplot(diamonds, aes(clarity)) + 
##D   geom_freqpoly(aes(group = cut, colour = cut))
##D 
##D # Dodged bar charts    
##D ggplot(diamonds, aes(clarity, fill=cut)) + geom_bar(position="dodge")
##D # compare with 
##D ggplot(diamonds, aes(cut, fill=cut)) + geom_bar() + 
##D   facet_grid(. ~ clarity)
##D 
##D # But again, probably better to use frequency polygons instead:
##D ggplot(diamonds, aes(clarity, colour=cut)) + 
##D   geom_freqpoly(aes(group = cut))
##D 
##D # Often we don't want the height of the bar to represent the
##D # count of observations, but the sum of some other variable.
##D # For example, the following plot shows the number of diamonds
##D # of each colour
##D qplot(color, data=diamonds, geom="bar")
##D # If, however, we want to see the total number of carats in each colour
##D # we need to weight by the carat variable
##D qplot(color, data=diamonds, geom="bar", weight=carat, ylab="carat")
##D 
##D # A bar chart used to display means
##D meanprice <- tapply(diamonds$price, diamonds$cut, mean)
##D cut <- factor(levels(diamonds$cut), levels = levels(diamonds$cut))
##D qplot(cut, meanprice)
##D qplot(cut, meanprice, geom="bar", stat="identity")
##D qplot(cut, meanprice, geom="bar", stat="identity", fill = I("grey50"))
## End(Not run)


